==> console-core-3.0-b48-sources.jar: js/restart.js <==
/* The contents of this file are subject to the terms 
 * of the Common Development and Distribution License 
 * (the License).  You may not use this file except in
 * compliance with the License.
 * 
 * You can obtain a copy of the license at 
 * https://glassfish.dev.java.net/public/CDDLv1.0.html or
 * glassfish/bootstrap/legal/CDDLv1.0.txt.
 * See the License for the specific language governing 
 * permissions and limitations under the License.
 * 
 * When distributing Covered Code, include this CDDL 
 * Header Notice in each file and include the License file 
 * at glassfish/bootstrap/legal/CDDLv1.0.txt.  
 * If applicable, add the following below the CDDL Header, 
 * with the fields enclosed by brackets [] replaced by
 * you own identifying information: 
 * "Portions Copyrighted [year] [name of copyright owner]"
 * 
 * Copyright 2006 Sun Microsystems, Inc. All rights reserved.
 */

/*===========================================================================*/
/* synchronizeRestartRequired */
/*===========================================================================*/
function synchronizeRestartRequired(currentRestartStatus, oldRestartStatus) {
    if (currentRestartStatus != oldRestartStatus) {
        reloadHeaderFrame();
        //showLargeHeaderFrame(true);
    }
    return true;
}

function reloadHeaderFrame() {
       parent.parent.frames["header"].location.reload();
}

function showLargeHeaderFrame(showLarge) {
    if (showLarge == true) {
        parent.parent.document.getElementById('outerFrameset').setAttribute('rows', '94,*', 0);
    } else {
        parent.parent.document.getElementById('outerFrameset').setAttribute('rows', '71,*', 0);
    }
}

==> console-core-10.0-b28-sources.jar: js/restart.js <==
/* The contents of this file are subject to the terms 
 * of the Common Development and Distribution License 
 * (the License).  You may not use this file except in
 * compliance with the License.
 * 
 * You can obtain a copy of the license at 
 * https://glassfish.dev.java.net/public/CDDLv1.0.html or
 * glassfish/bootstrap/legal/CDDLv1.0.txt.
 * See the License for the specific language governing 
 * permissions and limitations under the License.
 * 
 * When distributing Covered Code, include this CDDL 
 * Header Notice in each file and include the License file 
 * at glassfish/bootstrap/legal/CDDLv1.0.txt.  
 * If applicable, add the following below the CDDL Header, 
 * with the fields enclosed by brackets [] replaced by
 * you own identifying information: 
 * "Portions Copyrighted [year] [name of copyright owner]"
 * 
 * Copyright 2006 Sun Microsystems, Inc. All rights reserved.
 */

/*===========================================================================*/
/* synchronizeRestartRequired */
/*===========================================================================*/
function synchronizeRestartRequired(currentRestartStatus, oldRestartStatus) {
    if (currentRestartStatus != oldRestartStatus) {
        reloadHeaderFrame();
        showLargeHeaderFrame(true);
    }
    return true;
}

function reloadHeaderFrame() {
       parent.parent.frames["header"].location.reload();
}

function showLargeHeaderFrame(showLarge) {
    if (showLarge == true) {
        parent.parent.document.getElementById('outerFrameset').setAttribute('rows', '94,*', 0);
    } else {
        parent.parent.document.getElementById('outerFrameset').setAttribute('rows', '71,*', 0);
    }
}
